import 'dart:async';

import 'package:flutter/services.dart';

/// Result for [AccuracySetting]
/// will return NOT_IMPLIMENTED for API <= 18 or API >= 28
enum AccuracySettingMode {
  LOCATION_MODE_OFF,
  LOCATION_MODE_SENSORS_ONLY,
  LOCATION_MODE_BATTERY_SAVING,
  LOCATION_MODE_HIGH_ACCURACY,
  NOT_IMPLEMENTED,
}

/// Type of provider
/// Use for request isProviderEnabled
enum LocationProvider {
  GPS,
  NETWORK,
}

/// Static class
/// Directly call
class AccuracySetting {
  static const MethodChannel _channel = const MethodChannel('accuracy_setting');

  /// Get Accuracy Setting for Android > 18 and < 29
  /// return NOT_IMPLIMENTED for other android sdk
  static Future<AccuracySettingMode> getAccuracySetting() async {
    final int settingMode = await _channel.invokeMethod('getAccuracySetting');
    return AccuracySettingMode.values[settingMode];
  }

  /// Check for GPS provider is enabled
  /// Check for Network provider is enabled
  static Future<bool> getProviderEnabled(
      LocationProvider locationProvider) async {
    bool providerEnabled = false;

    if (locationProvider == LocationProvider.GPS) {
      providerEnabled = await _channel.invokeMethod('getGPSEnabled');
    } else if (locationProvider == LocationProvider.NETWORK) {
      providerEnabled = await _channel.invokeMethod('getNetworkEnabled');
    }
    return providerEnabled;
  }
}
